<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="14"/>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>軽量なファイルマネージャー</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="109"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="vanished">PCMan File Manager

Copyright (C) 2009 - 2013 洪任諭 (Hong Jen Yee)

　このプログラムはフリーソフトウェアです。
あなたはこれを、フリーソフトウェア財団によって発行された
GNU 一般公衆利用許諾契約書(バージョン2か、希望によっては
それ以降のバージョンのうちどれか)の定める条件の下で
再頒布または改変することができます。

　このプログラムは有用であることを願って頒布されますが、
*全くの無保証* です。
商業可能性の保証や特定の目的への適合性は、
言外に示されたものも含め全く存在しません。
詳しくはGNU 一般公衆利用許諾契約書をご覧ください。

　あなたはこのプログラムとともに、
GNU 一般公衆利用許諾契約書の複製物を1部
受け取ったはずです。もし受け取っていなければ、
フリーソフトウェア財団まで請求してください。
(宛先は the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.)</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://pcmanfm.sourceforge.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://pcmanfm.sourceforge.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://pcmanfm.sourceforge.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://pcmanfm.sourceforge.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="87"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>プログラム作成:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="78"/>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>PCMan File Manager

Copyright (C) 2009 - 2013 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="vanished">PCMan File Manager

Copyright (C) 2009 - 2013 洪任諭 (Hong Jen Yee)

　このプログラムはフリーソフトウェアです。
あなたはこれを、フリーソフトウェア財団によって発行された
GNU 一般公衆利用許諾契約書(バージョン2か、希望によっては
それ以降のバージョンのうちどれか)の定める条件の下で
再頒布または改変することができます。

　このプログラムは有用であることを願って頒布されますが、
*全くの無保証* です。
商業可能性の保証や特定の目的への適合性は、
言外に示されたものも含め全く存在しません。
詳しくはGNU 一般公衆利用許諾契約書をご覧ください。

　あなたはこのプログラムとともに、
GNU 一般公衆利用許諾契約書の複製物を1部
受け取ったはずです。もし受け取っていなければ、
フリーソフトウェア財団まで請求してください。
(宛先は the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.)</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="100"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>リムーバブルメディアが接続されました</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;リムーバブルメディアが接続されました&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>メディアの種類:</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>検出中...</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>実行させる処理を選んでください</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="23"/>
        <source>Anonymous &amp;login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="36"/>
        <source>Login as &amp;user:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="65"/>
        <source>Specify remote folder to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="72"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="79"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="86"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="96"/>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation type="unfinished">画像ファイル</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation type="unfinished">参照(&amp;B)</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>デスクトップの設定</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="30"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="52"/>
        <source>Wallpaper mode:</source>
        <translation>壁紙のモード:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="65"/>
        <source>Wallpaper image file:</source>
        <translation>壁紙の画像ファイル:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="85"/>
        <source>Select background color:</source>
        <translation>背景色を選択:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="94"/>
        <source>Image file</source>
        <translation>画像ファイル</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="100"/>
        <source>Image file path</source>
        <translation>画像ファイルのパス</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="107"/>
        <source>&amp;Browse</source>
        <translation>参照(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="119"/>
        <source>Icons</source>
        <translation type="unfinished">アイコン</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="125"/>
        <source>Icon size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="138"/>
        <source>Label Text</source>
        <translation>ラベルテキスト</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="176"/>
        <source>Select  text color:</source>
        <translation>文字色を選択</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="189"/>
        <source>Select shadow color:</source>
        <translation>影の色を選択:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="202"/>
        <source>Select font:</source>
        <translation>フォントを選択</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="225"/>
        <source>Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="231"/>
        <source>Minimum item margins:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="238"/>
        <source>3 px by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="241"/>
        <location filename="../../desktop-preferences.ui" line="265"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="254"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="261"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="278"/>
        <source>Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="315"/>
        <source>Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="321"/>
        <source>Enable Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="333"/>
        <source>Wallpaper image folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="340"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="347"/>
        <source> hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="357"/>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="370"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="373"/>
        <source>Interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="380"/>
        <source> minute(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="406"/>
        <source>Wallpaper folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="429"/>
        <source>Randomize the slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="459"/>
        <source>Window Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="465"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>デスクトップのクリック時にウインドウマネージャーのメニューを表示</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="453"/>
        <source>Advanced</source>
        <translation>高度</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>ファイルマネージャー</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="293"/>
        <source>Go Up</source>
        <translation>上へ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="296"/>
        <source>Alt+Up</source>
        <translation>Alt+Up</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="vanished">ホーム</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="308"/>
        <source>Alt+Home</source>
        <translation>Alt+Home</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="424"/>
        <source>Reload</source>
        <translation>再読込み</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="320"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="90"/>
        <source>Focus with Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="178"/>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="185"/>
        <source>Path &amp;Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="305"/>
        <source>&amp;Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="317"/>
        <source>&amp;Reload</source>
        <translation>再読込み(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="329"/>
        <source>Go</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="338"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="347"/>
        <source>&amp;About</source>
        <translation>情報(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="359"/>
        <source>New Window</source>
        <translation>新しいウインドウ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="362"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="370"/>
        <source>Show &amp;Hidden</source>
        <translation>隠しファイルを表示(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="373"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="382"/>
        <source>&amp;Computer</source>
        <translation>コンピューター(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="391"/>
        <source>&amp;Trash</source>
        <translation>ゴミ箱(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="396"/>
        <source>&amp;Network</source>
        <translation>ネットワーク(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="405"/>
        <source>&amp;Desktop</source>
        <translation>デスクトップ(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="414"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>ブックマークに追加(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="419"/>
        <source>&amp;Applications</source>
        <translation>アプリケーション(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="468"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="477"/>
        <source>&amp;Copy</source>
        <translation>コピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="480"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="489"/>
        <source>&amp;Paste</source>
        <translation>貼り付け(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="492"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="497"/>
        <source>Select &amp;All</source>
        <translation>すべてを選択(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="505"/>
        <source>Pr&amp;eferences</source>
        <translation>設定(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="513"/>
        <source>&amp;Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="521"/>
        <source>&amp;Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="529"/>
        <source>&amp;By File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="537"/>
        <source>By &amp;Modification Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="545"/>
        <source>By File &amp;Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="553"/>
        <source>By &amp;Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="561"/>
        <source>&amp;Folder First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="569"/>
        <source>&amp;Preserve sorting for this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>選択を反転(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="628"/>
        <source>&amp;Delete</source>
        <translation>削除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="636"/>
        <source>&amp;Rename</source>
        <translation>名前を変更(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="668"/>
        <source>&amp;Case Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="676"/>
        <source>By File &amp;Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="681"/>
        <source>&amp;Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="747"/>
        <source>&amp;Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="750"/>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="759"/>
        <source>Close &amp;previous tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="768"/>
        <source>Close &amp;next tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="807"/>
        <source>&amp;Preserve Settings for This Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="812"/>
        <source>Connect to &amp;Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="820"/>
        <source>&amp;Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="828"/>
        <source>&amp;Path Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="773"/>
        <source>Close &amp;other tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="781"/>
        <source>&amp;Menu bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="784"/>
        <source>Menu bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="787"/>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="796"/>
        <location filename="../../main-win.ui" line="799"/>
        <source>Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="500"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="290"/>
        <source>Go &amp;Up</source>
        <translation>上へ(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="356"/>
        <source>&amp;New Window</source>
        <translation>新しいウインドウ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="432"/>
        <source>&amp;Icon View</source>
        <translation>アイコン表示(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="440"/>
        <source>&amp;Compact View</source>
        <translation>コンパクト表示(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="448"/>
        <source>&amp;Detailed List</source>
        <translation>詳細リスト(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="456"/>
        <source>&amp;Thumbnail View</source>
        <translation>サムネイル表示(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="465"/>
        <source>Cu&amp;t</source>
        <translation>切り取り(&amp;T)</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="vanished">昇順</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="vanished">降順</translation>
    </message>
    <message>
        <source>By File Name</source>
        <translation type="vanished">名前</translation>
    </message>
    <message>
        <source>By Modification Time</source>
        <translation type="vanished">更新日時</translation>
    </message>
    <message>
        <source>By File Type</source>
        <translation type="vanished">種類</translation>
    </message>
    <message>
        <source>By Owner</source>
        <translation type="vanished">所有者</translation>
    </message>
    <message>
        <source>Folder First</source>
        <translation type="vanished">フォルダを先に</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="578"/>
        <source>New &amp;Tab</source>
        <translation>新しいタブ(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="581"/>
        <source>New Tab</source>
        <translation>新しいタブ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="584"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="593"/>
        <source>Go &amp;Back</source>
        <translation>戻る(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="596"/>
        <source>Go Back</source>
        <translation>戻る</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="599"/>
        <source>Alt+Left</source>
        <translation>Alt+Left</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="608"/>
        <source>Go &amp;Forward</source>
        <translation>進む(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="611"/>
        <source>Go Forward</source>
        <translation>進む</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="614"/>
        <source>Alt+Right</source>
        <translation>Alt+Right</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="631"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="639"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="644"/>
        <source>C&amp;lose Tab</source>
        <translation>タブを閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="652"/>
        <source>File &amp;Properties</source>
        <translation>ファイルのプロパティー(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="660"/>
        <source>&amp;Folder Properties</source>
        <translation>フォルダーのプロパティー(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="684"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="719"/>
        <source>Ctrl+Shift+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="731"/>
        <source>Ctrl+Alt+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="124"/>
        <source>C&amp;reate New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="152"/>
        <source>&amp;Sorting</source>
        <translation>ソート(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="261"/>
        <source>Main Toolbar</source>
        <translation>メインツールバー</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="647"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="655"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation type="vanished">大文字小文字を区別</translation>
    </message>
    <message>
        <source>By File Size</source>
        <translation type="vanished">サイズ</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="vanished">ウインドウを閉じる</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="689"/>
        <source>Edit Bookmarks</source>
        <translation>ブックマークを編集</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="694"/>
        <source>Open &amp;Terminal</source>
        <translation>端末で開く(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="697"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="702"/>
        <source>Open as &amp;Root</source>
        <translation>rootで開く(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="707"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>ブックマークを編集</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="716"/>
        <source>&amp;Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="728"/>
        <source>&amp;Blank File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="736"/>
        <source>&amp;Find Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="739"/>
        <source>F3</source>
        <translation type="unfinished">F3</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="93"/>
        <source>Filter by string...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="120"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="142"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="148"/>
        <location filename="../../main-win.ui" line="168"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="202"/>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="217"/>
        <source>&amp;Bookmarks</source>
        <translation>ブックマーク(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="224"/>
        <source>&amp;Go</source>
        <translation>開く(&amp;G)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="241"/>
        <source>&amp;Tool</source>
        <translation>ツール(&amp;T)</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../../application.cpp" line="170"/>
        <source>Name of configuration profile</source>
        <translation>設定プロファイルの名前</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="170"/>
        <source>PROFILE</source>
        <translation>PROFILE</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="173"/>
        <source>Run PCManFM as a daemon</source>
        <translation>PCManFMをデーモンとして実行</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="176"/>
        <source>Quit PCManFM</source>
        <translation>PCManFMを終了</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="179"/>
        <source>Launch desktop manager</source>
        <translation>デスクトップマネージャーを起動</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="182"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>実行中のデスクトップマネージャーを終了</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="185"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>特定の名前のページ上でデスクトップ設定ダイアログを開く</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="185"/>
        <location filename="../../application.cpp" line="200"/>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="194"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>画像ファイルからデスクトップの壁紙を設定</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="194"/>
        <source>FILE</source>
        <translation>FILE</translation>
    </message>
    <message>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation type="vanished">デスクトップの壁紙のモードを設定する。MODE=(color|stretch|fit|center|tile)</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="197"/>
        <source>MODE</source>
        <translation>MODE</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="200"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>特定の名前のページで設定ダイアログを開く</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="188"/>
        <source>Open new window</source>
        <translation>新しいウインドウを開く</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="191"/>
        <source>Open Find Files utility</source>
        <translation>ファイル検索ユーティリティーを開く</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="197"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="203"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2,...]</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="203"/>
        <source>Files or directories to open</source>
        <translation>開くファイルまたはディレクトリー</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="540"/>
        <location filename="../../application.cpp" line="545"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="545"/>
        <source>Terminal emulator is not set.</source>
        <translation>端末エミュレーターを未設定です</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../../autorundialog.cpp" line="45"/>
        <source>Open in file manager</source>
        <translation>ファイルマネージャーで開く</translation>
    </message>
    <message>
        <location filename="../../autorundialog.cpp" line="136"/>
        <source>Removable Disk</source>
        <translation>リムーバブルディスク</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>背景色のみで埋める</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>画面全部に引き伸ばす</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>画面に合わせて調節</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>画面の中央に表示</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>画面全体に並べる</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="204"/>
        <source>Image Files</source>
        <translation>画像ファイル</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../../desktopwindow.cpp" line="525"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>現在の場所に固定</translation>
    </message>
    <message>
        <location filename="../../desktopwindow.cpp" line="547"/>
        <source>Desktop Preferences</source>
        <translation>デスクトップ設定</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Clear text (Ctrl+K)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="343"/>
        <source>Hide menu bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="344"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="628"/>
        <source>Version: %1</source>
        <translation>バージョン: %1</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1263"/>
        <source>&amp;Move to Trash</source>
        <translation>ゴミ箱へ移動(&amp;M)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1263"/>
        <source>&amp;Delete</source>
        <translation>削除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1332"/>
        <location filename="../../mainwindow.cpp" line="1340"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1340"/>
        <source>Switch user command is not set.</source>
        <translation>ユーザー切替コマンドを未設定です</translation>
    </message>
    <message>
        <source>Terminal emulator is not set.</source>
        <translation type="vanished">端末エミュレーターを未設定です</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.cpp" line="195"/>
        <source>Icon View</source>
        <translation>アイコン表示</translation>
    </message>
    <message>
        <source>Compact Icon View</source>
        <translation type="vanished">小さなアイコン表示</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="196"/>
        <source>Compact View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="197"/>
        <source>Thumbnail View</source>
        <translation>サムネイル表示</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="198"/>
        <source>Detailed List View</source>
        <translation>詳細なリスト表示</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../../tabpage.cpp" line="279"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../../tabpage.cpp" line="292"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>空き領域: %1 (全体: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="309"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n 個のアイテム</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="311"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform>(%n 個の隠しアイテム)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="485"/>
        <source>%n item(s) selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 item(s) selected</source>
        <translation type="vanished">%1 個のアイテムを選択</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../../view.cpp" line="102"/>
        <source>Open in New T&amp;ab</source>
        <translation>新しいタブを開く(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="106"/>
        <source>Open in New Win&amp;dow</source>
        <translation>新しいウインドウを開く(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>端末内で開く(&amp;L)</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>ユーザーインターフェース</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>挙動</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="40"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="50"/>
        <location filename="../../preferences.ui" line="643"/>
        <source>Thumbnail</source>
        <translation>サムネイル</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>ボリューム</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="130"/>
        <source>Bookmarks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="138"/>
        <source>Open in current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="143"/>
        <source>Open in new tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="148"/>
        <source>Open in new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="179"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="186"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="193"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="220"/>
        <source>Icons</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="252"/>
        <source>Size of big icons:</source>
        <translation>大きいアイコンの大きさ:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="269"/>
        <source>Size of small icons:</source>
        <translation>小さいアイコンの大きさ:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="286"/>
        <source>Size of thumbnails:</source>
        <translation>サムネイルの大きさ:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="300"/>
        <source>Size of side pane icons:</source>
        <translation>サイドペインのアイコンの大きさ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="232"/>
        <source>Icon theme:</source>
        <translation>アイコンテーマ:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="456"/>
        <source>Window</source>
        <translation>ウインドウ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="501"/>
        <source>Default width of new windows:</source>
        <translation>新しいウインドウのデフォルト幅</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="515"/>
        <source>Default height of new windows:</source>
        <translation>新しいウインドウのデフォルトの高さ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="469"/>
        <source>Always show the tab bar</source>
        <translation>タブバーを常に表示</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="487"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>閉じるボタンをタブに表示</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="494"/>
        <source>Remember the size of the last closed window</source>
        <translation>直前に閉じたウインドウのサイズを記憶</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>ブラウジング</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="90"/>
        <source>Open files with single click</source>
        <translation>シングルクリックでファイルを開く</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="100"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>シングルクリックモードでの自動選択の遅延時間(0で無効)</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="107"/>
        <source>Default view mode:</source>
        <translation>デフォルトの表示モード</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="120"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="159"/>
        <source>File Operations</source>
        <translation>ファイル操作</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="165"/>
        <source>Confirm before deleting files</source>
        <translation>ファイルを削除する前に確認</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="172"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>ディスクから削除せずに&quot;ゴミ箱&quot;へ入れる</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="249"/>
        <location filename="../../preferences.ui" line="259"/>
        <source>Used by Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="266"/>
        <location filename="../../preferences.ui" line="276"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="283"/>
        <location filename="../../preferences.ui" line="293"/>
        <source>Used by Thumbnail View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="313"/>
        <source>User interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="326"/>
        <source>Treat backup files as hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="336"/>
        <source>Always show full file names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="346"/>
        <source>Show icons of hidden files shadowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="369"/>
        <source>Minimum item margins in icon view:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="376"/>
        <source>3 px by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="379"/>
        <location filename="../../preferences.ui" line="403"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="392"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="399"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="416"/>
        <source>Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="465"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="476"/>
        <source>If unchecked, the tab bar will be positioned only
above the folder-view and not above the left pane.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="480"/>
        <source>Fullwidth tab bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="532"/>
        <source>Show in places</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="539"/>
        <source>Home</source>
        <translation type="unfinished">ホーム</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="552"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="565"/>
        <source>Trash can</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="578"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="591"/>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="599"/>
        <source>Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="607"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="673"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="676"/>
        <source>Show thumbnails of files</source>
        <translation>ファイルのサムネイルを表示</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="836"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="842"/>
        <source>Show only user defined templates in menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="849"/>
        <source>Show only one template for each MIME type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="856"/>
        <source>Run default application after creation from template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="666"/>
        <source>Only show thumbnails for local files</source>
        <translation>ローカルファイルのみサムネイル表示</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="649"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>次のサイズを超える画像ファイルのサムネイルを生成しない:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="656"/>
        <source> KB</source>
        <translation> KB</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="733"/>
        <source>When removable medium unmounted:</source>
        <translation>リムーバブルメディアもアンマウントする際に:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="789"/>
        <source>Switch &amp;user command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="813"/>
        <source>Archiver in&amp;tegration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close tab containing removable medium</source>
        <translation type="vanished">リムーバブルメディアを表示しているタブを閉じる</translation>
    </message>
    <message>
        <source>Change folder in the tab to home folder</source>
        <translation type="vanished">そのタブのフォルダーをホームフォルダーに移動</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="782"/>
        <source>Terminal emulator:</source>
        <translation>端末エミュレーター:</translation>
    </message>
    <message>
        <source>Do not generate thumbnails for files exceeding this size (KB):</source>
        <translation type="vanished">次のサイズ(KB)を超えるファイルのサムネイルを生成しない:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="703"/>
        <source>Auto Mount</source>
        <translation>自動マウント</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="709"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>プログラム開始時にマウント可能なボリュームをマウントする</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="716"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>リムーバブルメディアが接続された際に自動的にマウントする</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="723"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>リムーバブルメディアが接続された際に、可能な処理を表示する</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="739"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="746"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="773"/>
        <source>Programs</source>
        <translation>プログラム</translation>
    </message>
    <message>
        <source>Terminal emulator command for directories:</source>
        <translation type="vanished">ディレクトリーで実行する端末エミュレーターのコマンド</translation>
    </message>
    <message>
        <source>Switch user command:</source>
        <translation type="vanished">ユーザーを切り替えるためのコマンド</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="802"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>例: 端末に &quot;xterm -e %s&quot; 、ユーザー切替に &quot;gksu %s&quot;
%s には、端末やsuで実行するコマンドが代入されます</translation>
    </message>
    <message>
        <source>Archiver integration:</source>
        <translation type="vanished">アーカイバー連係:</translation>
    </message>
    <message>
        <source>Terminal emulator command for programs:</source>
        <translation type="vanished">プログラムを実行する端末エミュレーターのコマンド:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="319"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>IEC二進接頭辞の代わりに、SI十進接頭辞を用いる</translation>
    </message>
</context>
</TS>
